@@ -22,7 +22,7 @@ from optparse import make_option
 from jhbuild.errors import UsageError, FatalError
 from jhbuild.commands import Command, BuildCommand, register_command
 import jhbuild.frontends
-import optparse
+from jhbuild.utils import N_, _
 
 
 class cmd_tinderbox(BuildCommand):
@@ -34,8 +34,11 @@ class cmd_tinderbox(BuildCommand):
     def __init__(self):
         Command.__init__(self, [
             make_option('-a', '--autogen',
-                        action='store_true', dest='_unused', default=False,
-                        help=optparse.SUPPRESS_HELP), # no longer used
+                        action='store_true', dest='autogen', default=False,
+                        help=_('always run autogen.sh')),
+            make_option('', '--distclean',
+                        action='store_true', dest='distclean', default=False,
+                        help=_('completely clean source tree')),
             make_option('-c', '--clean',
                         action='store_true', dest='clean', default=False,
                         help=_('run make clean before make')),
@@ -79,8 +82,8 @@ class cmd_tinderbox(BuildCommand):
             raise UsageError(_('output directory for tinderbox build not specified'))
 
         module_set = jhbuild.moduleset.load(config)
-        full_module_list = module_set.get_full_module_list \
-                               (args or config.modules, config.skip)
+        full_module_list = module_set.get_full_module_list(
+            args or config.modules, config.skip)
         module_list = module_set.remove_system_modules(full_module_list)
 
         # remove modules up to startat
@@ -91,7 +94,7 @@ class cmd_tinderbox(BuildCommand):
                 raise FatalError(_('%s not in module list') % options.startat)
 
         if config.check_sysdeps:
-            module_state = module_set.get_system_modules(full_module_list)
+            module_state = module_set.get_module_state(full_module_list)
             if not self.required_system_dependencies_installed(module_state):
                 self.print_system_dependencies(module_state)
                 raise FatalError(_('Required system dependencies not installed.'
